==> pixi-0.50.0-crates.tar.xz: cargo_home/gentoo/file_url-0.2.5/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.5](https://github.com/conda/rattler/compare/file_url-v0.2.4...file_url-v0.2.5) - 2025-05-16

### Other

- update dependencies ([#1126](https://github.com/conda/rattler/pull/1126))

## [0.2.4](https://github.com/conda/rattler/compare/file_url-v0.2.3...file_url-v0.2.4) - 2025-04-04

### Other

- update Cargo.toml dependencies

## [0.2.3](https://github.com/conda/rattler/compare/file_url-v0.2.2...file_url-v0.2.3) - 2025-02-18

### Other

- update dependencies (#1069)

## [0.2.2](https://github.com/conda/rattler/compare/file_url-v0.2.1...file_url-v0.2.2) - 2025-01-08

### Other

- update dependencies (#1009)

## [0.2.1](https://github.com/conda/rattler/compare/file_url-v0.2.0...file_url-v0.2.1) - 2024-12-17

### Other

- update everything (#987)

## [0.2.0](https://github.com/conda/rattler/compare/file_url-v0.1.7...file_url-v0.2.0) - 2024-11-30

### Added

- merge pixi-build branch ([#950](https://github.com/conda/rattler/pull/950))

## [0.1.7](https://github.com/conda/rattler/compare/file_url-v0.1.6...file_url-v0.1.7) - 2024-11-04

### Other

- update all versions of packages ([#886](https://github.com/conda/rattler/pull/886))

## [0.1.6](https://github.com/conda/rattler/compare/file_url-v0.1.5...file_url-v0.1.6) - 2024-10-21

### Other

- update Cargo.toml dependencies

## [0.1.5](https://github.com/conda/rattler/compare/file_url-v0.1.4...file_url-v0.1.5) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [0.1.4](https://github.com/conda/rattler/compare/file_url-v0.1.3...file_url-v0.1.4) - 2024-08-15

### Fixed
- use conda-incubator

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))

## [0.1.3](https://github.com/conda/rattler/compare/file_url-v0.1.2...file_url-v0.1.3) - 2024-07-15

### Other
- update Cargo.toml dependencies

## [0.1.2](https://github.com/baszalmstra/rattler/compare/file_url-v0.1.1...file_url-v0.1.2) - 2024-06-04

### Added
- parse url and path as matchspec ([#704](https://github.com/baszalmstra/rattler/pull/704))

## [0.1.1](https://github.com/conda/rattler/compare/file_url-v0.1.0...file_url-v0.1.1) - 2024-05-14

### Added
- exclude repodata records based on timestamp ([#654](https://github.com/conda/rattler/pull/654))

==> pixi-0.59.0-crates.tar.xz: cargo_home/gentoo/file_url-0.2.6/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.6](https://github.com/conda/rattler/compare/file_url-v0.2.5...file_url-v0.2.6) - 2025-07-21

### Other

- bump rust 1.88.0 ([#1536](https://github.com/conda/rattler/pull/1536))

## [0.2.5](https://github.com/conda/rattler/compare/file_url-v0.2.4...file_url-v0.2.5) - 2025-05-16

### Other

- update dependencies ([#1126](https://github.com/conda/rattler/pull/1126))

## [0.2.4](https://github.com/conda/rattler/compare/file_url-v0.2.3...file_url-v0.2.4) - 2025-04-04

### Other

- update Cargo.toml dependencies

## [0.2.3](https://github.com/conda/rattler/compare/file_url-v0.2.2...file_url-v0.2.3) - 2025-02-18

### Other

- update dependencies (#1069)

## [0.2.2](https://github.com/conda/rattler/compare/file_url-v0.2.1...file_url-v0.2.2) - 2025-01-08

### Other

- update dependencies (#1009)

## [0.2.1](https://github.com/conda/rattler/compare/file_url-v0.2.0...file_url-v0.2.1) - 2024-12-17

### Other

- update everything (#987)

## [0.2.0](https://github.com/conda/rattler/compare/file_url-v0.1.7...file_url-v0.2.0) - 2024-11-30

### Added

- merge pixi-build branch ([#950](https://github.com/conda/rattler/pull/950))

## [0.1.7](https://github.com/conda/rattler/compare/file_url-v0.1.6...file_url-v0.1.7) - 2024-11-04

### Other

- update all versions of packages ([#886](https://github.com/conda/rattler/pull/886))

## [0.1.6](https://github.com/conda/rattler/compare/file_url-v0.1.5...file_url-v0.1.6) - 2024-10-21

### Other

- update Cargo.toml dependencies

## [0.1.5](https://github.com/conda/rattler/compare/file_url-v0.1.4...file_url-v0.1.5) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [0.1.4](https://github.com/conda/rattler/compare/file_url-v0.1.3...file_url-v0.1.4) - 2024-08-15

### Fixed
- use conda-incubator

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))

## [0.1.3](https://github.com/conda/rattler/compare/file_url-v0.1.2...file_url-v0.1.3) - 2024-07-15

### Other
- update Cargo.toml dependencies

## [0.1.2](https://github.com/baszalmstra/rattler/compare/file_url-v0.1.1...file_url-v0.1.2) - 2024-06-04

### Added
- parse url and path as matchspec ([#704](https://github.com/baszalmstra/rattler/pull/704))

## [0.1.1](https://github.com/conda/rattler/compare/file_url-v0.1.0...file_url-v0.1.1) - 2024-05-14

### Added
- exclude repodata records based on timestamp ([#654](https://github.com/conda/rattler/pull/654))
